@@ -3,7 +3,7 @@ import sys
 import traceback
 
 from optparse import make_option
-from subprocess import Popen, PIPE, STDOUT
+from subprocess import Popen, PIPE
 
 from django.db import connections, transaction, DEFAULT_DB_ALIAS
 from django.db.models import get_model
@@ -13,7 +13,7 @@ from django.core.management.base import BaseCommand, CommandError
 from django.core.management.sql import emit_post_sync_signal
 
 from nashvegas.models import Migration
-from nashvegas.utils import get_sql_for_new_models, get_db_exec_args
+from nashvegas.utils import get_sql_for_new_models
 
 
 sys.path.append("migrations")
@@ -78,7 +78,7 @@ class Command(BaseCommand):
                     scripts_in_directory.append((number, script))
             
             for number, script in scripts_in_directory:
-                if script not in applied and number < stop_at:
+                if script not in applied and number <= stop_at:
                     to_execute.append(script)
         except OSError, e:
             print str(e)
@@ -122,7 +122,6 @@ class Command(BaseCommand):
     def create_migrations(self):
         statements = get_sql_for_new_models()
         if len(statements) > 0:
-            print "BEGIN;"
             for s in statements:
                 print s
     
@@ -191,7 +190,7 @@ class Command(BaseCommand):
                     content=content,
                     scm_version=self._get_rev(migration_path)
                 )
-        except Exception, e:
+        except Exception:
             transaction.rollback(using=self.db)
             sys.stdout.write("Rolled back all migrations\n")
             sys.exit(1)
